import { FieldErrors, FieldValues, ResolverOptions } from 'react-hook-form';
export declare const validateFieldsNatively: <TFieldValues extends FieldValues>(errors: FieldErrors, options: ResolverOptions<TFieldValues>) => void;
